@@ -186,10 +186,9 @@ def C(im):
     else:
         return np.repeat(im[...,None], 3, 2)
 
-def isdir(fpath): return '.' not in fpath.split('/')[-1]
+def isdir(fpath): return os.path.isdir(fpath)
 def makedir(x):
-    if isdir(x): makedir(parent(x))
-    else       : os.makedirs(x, exist_ok=True)
+    os.makedirs(x, exist_ok=True)
 
 fname = lambda fpath: fpath.split('/')[-1]
 fname2 = lambda fpath: stem(fpath.split('/')[-1])
@@ -359,7 +358,8 @@ def dumpdill(obj, fpath, silent=False):
         dill.dump(obj, f)
     if not silent:
         fsize = os.path.getsize(fpath) >> 20
-        logger.opt(depth=1).log('INFO', f'Dumped object of size `~{fsize} MB` @ "{fpath}" in {time.time()-start:.2f} seconds')
+        fsize = f'{fsize} MB' if fsize > 0 else f'{os.path.getsize(fpath) >> 10} KB'
+        logger.opt(depth=1).log('INFO', f'Dumped object of size ≈{fsize} @ "{fpath}" in {time.time()-start:.2e} seconds')
 
 def loaddill(fpath):
     with open(fpath, 'rb') as f:
